@@ -17,13 +17,14 @@ from .plot import Plot, PlotObj, xyz_to_points
 from .onlinetex import tex_to_svg_file_online
 import manimlib.mobject.svg.tex_mobject
 from pyglet.window import key
+from .jupyter import JupyterDisplay
+from pathlib import Path
+from .jupyter import video
 
-__all__ = ["EagerModeScene", "JupyterModeScene", "Size", "SceneArgs", "PlotObj", "xyz_to_points"]
+__all__ = ["EagerModeScene", "JupyterModeScene", "Size", "CONFIG", "PlotObj", "xyz_to_points"]
 
 
-class SceneArgs:
-    # write_file = False
-    # file_name = None
+class CONFIG:
     # skip_animations = False  # "Save the last frame"
     color = None  # Background color"
     full_screen = False
@@ -39,7 +40,9 @@ class SceneArgs:
     quiet = True
     open = False  # Automatically open the saved file once its done
     finder = False  # Show the output file in finder
-    frame_rate = None
+    frame_rate = 30
+    write_file = False
+    file_name = None
     video_dir = None  # directory to write video
     start_at_animation_number = None
     use_online_tex = False
@@ -48,28 +51,25 @@ class SceneArgs:
 class EagerModeScene(Scene):
     def __init__(
             self,
-            write_file=False,
-            file_name=None,
             screen_size=Size.big,
             scene_name='EagerModeScene',
-            CONFIG=None,
+            # CONFIG=None,
     ):
-        self.CONFIG = CONFIG
+        # self.CONFIG = CONFIG
         args = manimlib.config.parse_cli()
         args_dict = vars(args)
         args_dict['file'] = None
         args_dict['scene_names'] = scene_name
         args_dict['screen_size'] = screen_size
-        for key, value in SceneArgs.__dict__.items():
+        for key, value in CONFIG.__dict__.items():
             args_dict[key] = value
 
-        if write_file is True or SceneArgs.gif is True:
+        if CONFIG.gif is True:
             args_dict['write_file'] = True
-            args_dict['file_name'] = file_name
-            if SceneArgs.gif is True:
-                args_dict["transparent"] = False
+            # if CONFIG.gif is True:
+            #     args_dict["transparent"] = False
 
-        if SceneArgs.use_online_tex:
+        if CONFIG.use_online_tex:
             print("Use online latex compiler")
             manimlib.mobject.svg.tex_mobject.tex_to_svg_file = tex_to_svg_file_online
 
@@ -166,6 +166,9 @@ class EagerModeScene(Scene):
         if self.window and self.linger_after_completion:
             self.interact()
 
+    def tear_down(self):
+        super().tear_down()
+
     def get_config(self):
         return self.config
 
@@ -257,13 +260,22 @@ class JupyterModeScene(EagerModeScene):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-    def hold_on(self):
+    def finish(self):
         self.file_writer.finish()
 
     def embed(self):
         """We don't need it in jupyter lab/notebook."""
         pass
 
+    @property
+    def video_path(self):
+        self.file_writer.finish()
+        path = Path(self.file_writer.get_movie_file_path())
+        relative_path = path.relative_to(Path.cwd())
+        # video(relative_path)
+        return relative_path
+
+
     def quit(self):
         """Please use exit() or quit() in jupyter cell."""
         pass
